@@ -1,18 +1,9 @@
 #!/usr/bin/env python3
-
+# SPDX-License-Identifier: Apache-2.0
 # Copyright 2012-2021 The Meson development team
+# Copyright © 2023-2024 Intel Corporation
 
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-
-#     http://www.apache.org/licenses/LICENSE-2.0
-
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+from __future__ import annotations
 
 # Work around some pathlib bugs...
 from mesonbuild import _pathlib
@@ -45,6 +36,9 @@ from mesonbuild.environment import Environment, detect_ninja, detect_machine_inf
 from mesonbuild.coredata import backendlist, version as meson_version
 from mesonbuild.mesonlib import OptionKey, setup_vsenv
 
+if T.TYPE_CHECKING:
+    from mesonbuild.coredata import SharedCMDOptions
+
 NINJA_1_9_OR_NEWER = False
 NINJA_CMD = None
 # If we're on CI, detecting ninja for every subprocess unit test that we run is slow
@@ -145,9 +139,8 @@ class FakeCompilerOptions:
     def __init__(self):
         self.value = []
 
-# TODO: use a typing.Protocol here
-def get_fake_options(prefix: str = '') -> argparse.Namespace:
-    opts = argparse.Namespace()
+def get_fake_options(prefix: str = '') -> SharedCMDOptions:
+    opts = T.cast('SharedCMDOptions', argparse.Namespace())
     opts.native_file = []
     opts.cross_file = None
     opts.wrap_mode = None
