@@ -1,21 +1,11 @@
+# SPDX-License-Identifier: Apache-2.0
 # Copyright 2016-2021 The Meson development team
 
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-
-#     http://www.apache.org/licenses/LICENSE-2.0
-
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-
 import re
 import unittest
 from itertools import chain
 from pathlib import Path
+from unittest import mock
 
 import mesonbuild.mlog
 import mesonbuild.depfile
@@ -219,24 +209,36 @@ class DataTests(unittest.TestCase):
             name = name.replace('_', '-')
             self.assertIn(name, html)
 
+    @mock.patch.dict(os.environ)
+    @mock.patch.object(Interpreter, 'load_root_meson_file', mock.Mock(return_value=None))
+    @mock.patch.object(Interpreter, 'sanity_check_ast', mock.Mock(return_value=None))
+    @mock.patch.object(Interpreter, 'parse_project', mock.Mock(return_value=None))
     def test_vim_syntax_highlighting(self):
         '''
         Ensure that vim syntax highlighting files were updated for new
         functions in the global namespace in build files.
         '''
+        # Disable unit test specific syntax
+        del os.environ['MESON_RUNNING_IN_PROJECT_TESTS']
         env = get_fake_env()
-        interp = Interpreter(FakeBuild(env), mock=True)
+        interp = Interpreter(FakeBuild(env))
         with open('data/syntax-highlighting/vim/syntax/meson.vim', encoding='utf-8') as f:
             res = re.search(r'syn keyword mesonBuiltin(\s+\\\s\w+)+', f.read(), re.MULTILINE)
             defined = set([a.strip() for a in res.group().split('\\')][1:])
             self.assertEqual(defined, set(chain(interp.funcs.keys(), interp.builtin.keys())))
 
+    @mock.patch.dict(os.environ)
+    @mock.patch.object(Interpreter, 'load_root_meson_file', mock.Mock(return_value=None))
+    @mock.patch.object(Interpreter, 'sanity_check_ast', mock.Mock(return_value=None))
+    @mock.patch.object(Interpreter, 'parse_project', mock.Mock(return_value=None))
     def test_all_functions_defined_in_ast_interpreter(self):
         '''
         Ensure that the all functions defined in the Interpreter are also defined
         in the AstInterpreter (and vice versa).
         '''
+        # Disable unit test specific syntax
+        del os.environ['MESON_RUNNING_IN_PROJECT_TESTS']
         env = get_fake_env()
-        interp = Interpreter(FakeBuild(env), mock=True)
+        interp = Interpreter(FakeBuild(env))
         astint = AstInterpreter('.', '', '')
         self.assertEqual(set(interp.funcs.keys()), set(astint.funcs.keys()))
